using System;
using System.Collections.Generic;
using System.Drawing.Design;
using System.Windows.Forms;

using DataDynamics.ActiveReports.Design;

namespace DataDynamics.ActiveReports.Samples.Professional.EndUserDesigner
{
	public partial class EndUserDesignerMainForm : Form
	{
		public EndUserDesignerMainForm()
		{
			InitializeComponent();

			//Create new report instance and assign to Report Explorer
			//Note:  Assigning the ToolBox to the designer before calling NewReport
			// will automaticly add the default controls to the toolbox in a group called
			// "ActiveReports 6"           
            //arToolbox.GetGroups()[0].Text = "Tools";
            
			arDesigner.Toolbox = arToolbox;
            arToolbox.GetGroups()[0].Text = "raji";
            arReportExplorer.ReportDesigner = arDesigner;

			// Add Menu and CommandBar to Form
			ToolStrip menuStrip = arDesigner.CreateToolStrips(DesignerToolStrips.Menu)[0];

			ToolStripDropDownItem fileMenu = (ToolStripDropDownItem)menuStrip.Items[0];

			// Add a Export to RDF and Exit command to the File menu
			fileMenu.DropDownItems.Add(new ToolStripButton("Export to RDF...", null, DoExportRdf));
			fileMenu.DropDownItems.Add(new ToolStripSeparator());
			fileMenu.DropDownItems.Add(new ToolStripButton("Exit", null, OnExit));

			AppendToolStrips(0, new ToolStrip[] {menuStrip});
			AppendToolStrips(1, arDesigner.CreateToolStrips(
				DesignerToolStrips.Report,
				DesignerToolStrips.Edit,
				DesignerToolStrips.Undo,
				DesignerToolStrips.Zoom));

			AppendToolStrips(2, arDesigner.CreateToolStrips(
				DesignerToolStrips.Format, DesignerToolStrips.Layout));

			//Fill Toolbox
			LoadTools(this.arToolbox);

            
            // Activate default group on the toolbox
			this.arToolbox.SelectedCategory = "raji";

            //(arDesigner.Toolbox as DataDynamics.ActiveReports.Design.Toolbox.Toolbox).GetGroups()[0].Text = "ARTools";
		}


		private void AppendToolStrips(int row, IList<ToolStrip> toolStrips)
		{
			ToolStripPanel panel = toolStripContainer1.TopToolStripPanel;
			for (int i = toolStrips.Count; --i >= 0; )
			{
				panel.Join(toolStrips[i], row);
			}
		}

		private static void LoadTools(IToolboxService toolbox)
		{
			//Add Data Providers
			foreach (Type type in new Type[]
				{
					typeof (System.Data.DataSet),
					typeof (System.Data.DataView),
					typeof (System.Data.OleDb.OleDbConnection),
					typeof (System.Data.OleDb.OleDbDataAdapter),
					typeof (System.Data.Odbc.OdbcConnection),
					typeof (System.Data.Odbc.OdbcDataAdapter),
					typeof (System.Data.SqlClient.SqlConnection),
					typeof (System.Data.SqlClient.SqlDataAdapter)
				})
			{
				toolbox.AddToolboxItem(new ToolboxItem(type), "Data");
			}
		}

		/// <summary>
		/// OnExit
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void OnExit(object sender, EventArgs e)
		{
			Close();
		}

		private void DoExportRdf(object sender, EventArgs e)
		{
			SaveFileDialog saveRdfDialog = new SaveFileDialog();
			saveRdfDialog.Filter = "RDF files (*.rdf)|*.rdf|All files (*.*)|*.*";
			if (saveRdfDialog.ShowDialog() == DialogResult.OK)
			{
				arDesigner.Report.Run(false);
				arDesigner.Report.Document.Save(saveRdfDialog.FileName);
			}
		}

		#region Designer Events

		private void arDesigner_SelectionChanged()
		{
			List<string> selectionItems = new List<string>();
			if (arDesigner.Selection != null)
			{
				foreach (object item in arDesigner.Selection)
				{
					string itemName;
					if (item is Section)
						itemName = ((Section)item).Name;
					else if (item is ARControl)
						itemName = ((ARControl)item).Name;
					else if (item is Field)
						itemName = ((Field)item).Name;
					else if (item is Parameter)
						itemName = ((Parameter)item).Key;
					else if (item is ActiveReport)
						itemName = ((ActiveReport)item).Document.Name;
					else
						continue;

					selectionItems.Add(itemName);
				}
			}

			if (selectionItems.Count > 0)
				toolStripStatusLabel2.Text = "Current Selection: " + string.Join(", ", selectionItems.ToArray());
			else
				toolStripStatusLabel2.Text = "No Selection";
		}

		private void arDesigner_LayoutChanged(object sender, LayoutChangedArgs e)
		{

		}

		#endregion

		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		private static void Main()
		{
			Application.Run(new EndUserDesignerMainForm());
		}

        private string _defaultConString = "Provider=Microsoft.Jet.OLEDB.4.0;Data Source=C:\\NWIND.MDB;Persist Security Info=False";
        private void arDesigner_DataSourceIconClick(object sender, DataSourceIconClickEventArgs e)
        {
            string reportQuery = string.Empty;
            e.Cancel = true;

            SQLQueryBuilder.SQLQueryBuilder sqlQueryBuilder = new SQLQueryBuilder.SQLQueryBuilder();
            // assign the connection string
            sqlQueryBuilder.ConnectionString = this._defaultConString;
            
            // call showdialog and get the info based on dialog result
            if (sqlQueryBuilder.ShowDialog() == DialogResult.Cancel)
                return;

            
            reportQuery = sqlQueryBuilder.ReportQuery;
            

            DataDynamics.ActiveReports.DataSources.OleDBDataSource oledbDS = new DataSources.OleDBDataSource();
            oledbDS.ConnectionString = this._defaultConString;
            oledbDS.SQL = sqlQueryBuilder.ReportQuery;

            this.arDesigner.Report.DataSource = oledbDS;
        }
	}
}